@@ -30,8 +30,8 @@ class Module(AuxDataContainer):
     :ivar ~.isa: The ISA of the binary.
     :ivar ~.file_format: The file format of the binary.
     :ivar ~.name: The name given to the binary. Some file formats use this
-        for linking and/or symbol resolution purposes. An empty string if
-        not specified by the format.
+        for linking and/or symbol resolution purposes. The file name (without
+        directory components) if not specified by the format.
     :ivar ~.preferred_addr: The preferred loading address of the binary.
     :ivar ~.proxies: A set containing all the :class:`gtirb.ProxyBlock`\\s
         in the binary.
@@ -147,11 +147,11 @@ class Module(AuxDataContainer):
     def __init__(
         self,
         *,
+        name,  # type: str
         aux_data=dict(),  # type: DictLike[str, AuxData]
         binary_path="",  # type: str
         file_format=FileFormat.Undefined,  # type: Module.FileFormat
         isa=ISA.Undefined,  # type: Module.ISA
-        name="",  # type: str
         preferred_addr=0,  # type: int
         proxies=set(),  # type: typing.Iterable[ProxyBlock]
         rebase_delta=0,  # type: int
